Exception: Noise::Exceptions::HandshakeTurnError

Inherits:
NoiseHandshakeError show all
Defined in:
lib/noise/exceptions/handshake_turn_error.rb

Overview

Raised when a handshake message is written where one has to be read, or read where one has to be written. A Noise handshake alternates between the two parties, so only one of the two is legal at any point.